# slither-documentation

`slither-documentation` uses [codex](https://platform.openai.com) to generate natspec documentation.

This tool is experimental. See [solmate documentation](https://github.com/montyly/solmate/pull/1) for an example of usage.
